==> aliyun-python-sdk-retailcloud-2.0.12.tar.gz: aliyun-python-sdk-retailcloud-2.0.12/aliyunsdkretailcloud/request/v20180313/ResetAccountPasswordRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkretailcloud.endpoint import endpoint_data

class ResetAccountPasswordRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'retailcloud', '2018-03-13', 'ResetAccountPassword','retailcloud')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_AccountPassword(self):
		return self.get_body_params().get('AccountPassword')

	def set_AccountPassword(self,AccountPassword):
		self.add_body_params('AccountPassword', AccountPassword)

	def get_AccountName(self):
		return self.get_body_params().get('AccountName')

	def set_AccountName(self,AccountName):
		self.add_body_params('AccountName', AccountName)

	def get_DbInstanceId(self):
		return self.get_body_params().get('DbInstanceId')

	def set_DbInstanceId(self,DbInstanceId):
		self.add_body_params('DbInstanceId', DbInstanceId)

==> aliyun-python-sdk-retailcloud-2.0.20.tar.gz: aliyun-python-sdk-retailcloud-2.0.20/aliyunsdkretailcloud/request/v20180313/ResetAccountPasswordRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkretailcloud.endpoint import endpoint_data

class ResetAccountPasswordRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'retailcloud', '2018-03-13', 'ResetAccountPassword')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_AccountPassword(self): # String
		return self.get_body_params().get('AccountPassword')

	def set_AccountPassword(self, AccountPassword):  # String
		self.add_body_params('AccountPassword', AccountPassword)
	def get_AccountName(self): # String
		return self.get_body_params().get('AccountName')

	def set_AccountName(self, AccountName):  # String
		self.add_body_params('AccountName', AccountName)
	def get_DbInstanceId(self): # String
		return self.get_body_params().get('DbInstanceId')

	def set_DbInstanceId(self, DbInstanceId):  # String
		self.add_body_params('DbInstanceId', DbInstanceId)
